@@ -5,17 +5,16 @@ import fnmatch
 import glob
 import os
 import re
-from abc import ABCMeta, abstractmethod
+from abc import ABC, abstractmethod
 
 from diff_cover.git_diff import GitDiffError
 
 
-class BaseDiffReporter:
+class BaseDiffReporter(ABC):
     """
     Query information about lines changed in a diff.
     """
 
-    __metaclass__ = ABCMeta
     _exclude = None
     _include = None
 
@@ -113,6 +112,7 @@ class GitDiffReporter(BaseDiffReporter):
         git_diff=None,
         ignore_staged=None,
         ignore_unstaged=None,
+        include_untracked=False,
         supported_extensions=None,
         exclude=None,
         include=None,
@@ -127,6 +127,8 @@ class GitDiffReporter(BaseDiffReporter):
             options.append("staged")
         if not ignore_unstaged:
             options.append("unstaged")
+        if include_untracked:
+            options.append("untracked")
 
         # Branch is always present, so use as basis for name
         name = f"{compare_branch}...HEAD"
@@ -143,6 +145,7 @@ class GitDiffReporter(BaseDiffReporter):
         self._git_diff_tool = git_diff
         self._ignore_staged = ignore_staged
         self._ignore_unstaged = ignore_unstaged
+        self._include_untracked = include_untracked
         self._supported_extensions = supported_extensions
 
         # Cache diff information as a dictionary
@@ -163,6 +166,13 @@ class GitDiffReporter(BaseDiffReporter):
         # Get the diff dictionary
         diff_dict = self._git_diff()
 
+        # include untracked files
+        if self._include_untracked:
+            for path in self._git_diff_tool.untracked():
+                with open(path) as file_handle:
+                    num_lines = len(file_handle.readlines())
+                diff_dict[path] = list(range(1, num_lines + 1))
+
         # Return the changed file paths (dict keys)
         # in alphabetical order
         return sorted(diff_dict.keys(), key=lambda x: x.lower())
@@ -214,7 +224,7 @@ class GitDiffReporter(BaseDiffReporter):
                 # Parse the output of the diff string
                 diff_dict = self._parse_diff_str(diff_str)
 
-                for src_path in diff_dict:
+                for src_path, (added_lines, deleted_lines) in diff_dict.items():
                     if self._is_path_excluded(src_path):
                         continue
                     # If no _supported_extensions provided, or extension present: process
@@ -225,8 +235,6 @@ class GitDiffReporter(BaseDiffReporter):
                         not self._supported_extensions
                         or extension in self._supported_extensions
                     ):
-                        added_lines, deleted_lines = diff_dict[src_path]
-
                         # Remove any lines from the dict that have been deleted
                         # Include any lines that have been added
                         result_dict[src_path] = [
@@ -402,8 +410,6 @@ class GitDiffReporter(BaseDiffReporter):
                     current_line_new += 1
 
                 # If we are not in a hunk, then ignore the line
-                else:
-                    pass
 
         return added_lines, deleted_lines
 
@@ -488,4 +494,4 @@ class GitDiffReporter(BaseDiffReporter):
         line_set = set(line_numbers)
 
         # Retrieve the list from the set, sort it, and return
-        return sorted([line for line in line_set])
+        return sorted(line for line in line_set)
