@@ -23,7 +23,7 @@ class XmlCoverageReporter(BaseViolationReporter):
     Query information from a Cobertura|Clover|JaCoCo XML coverage report.
     """
 
-    def __init__(self, xml_roots, src_roots=[""]):
+    def __init__(self, xml_roots, src_roots=None):
         """
         Load the XML coverage report represented
         by the cElementTree with root element `xml_root`.
@@ -35,7 +35,7 @@ class XmlCoverageReporter(BaseViolationReporter):
         # Keys are source file paths, values are output of `violations()`
         self._info_cache = defaultdict(list)
 
-        self._src_roots = src_roots
+        self._src_roots = src_roots or [""]
 
     @staticmethod
     def _to_unix_path(path):
@@ -81,7 +81,7 @@ class XmlCoverageReporter(BaseViolationReporter):
         # within it. If we have that we outta use it
         sources = xml_document.findall("sources/source")
         sources = [source.text for source in sources if source.text]
-        classes = [class_tree for class_tree in xml_document.findall(".//class") or []]
+        classes = xml_document.findall(".//class") or []
 
         classes = (
             [
@@ -113,9 +113,8 @@ class XmlCoverageReporter(BaseViolationReporter):
 
         if not classes:
             return None
-        else:
-            lines = [clazz.findall("./lines/line") for clazz in classes]
-            return [elem for elem in itertools.chain(*lines)]
+        lines = [clazz.findall("./lines/line") for clazz in classes]
+        return list(itertools.chain(*lines))
 
     @staticmethod
     def get_src_path_line_nodes_clover(xml_document, src_path):
@@ -129,7 +128,7 @@ class XmlCoverageReporter(BaseViolationReporter):
         files = [
             file_tree
             for file_tree in xml_document.findall(".//file")
-            if GitPathTool.relative_path(file_tree.get("path")) == src_path or []
+            if GitPathTool.relative_path(file_tree.get("path")) == src_path
         ]
         if not files:
             return None
@@ -137,12 +136,12 @@ class XmlCoverageReporter(BaseViolationReporter):
         for file_tree in files:
             lines.append(file_tree.findall('./line[@type="stmt"]'))
             lines.append(file_tree.findall('./line[@type="cond"]'))
-        return [elem for elem in itertools.chain(*lines)]
+        return list(itertools.chain(*lines))
 
     def _measured_source_path_matches(self, package_name, file_name, src_path):
         # find src_path in any of the source roots
         if not src_path.endswith(file_name):
-            return None
+            return False
 
         norm_src_path = os.path.normcase(src_path)
         for root in self._src_roots:
@@ -155,6 +154,7 @@ class XmlCoverageReporter(BaseViolationReporter):
                 == norm_src_path
             ):
                 return True
+        return False
 
     def get_src_path_line_nodes_jacoco(self, xml_document, src_path):
         """
@@ -165,7 +165,7 @@ class XmlCoverageReporter(BaseViolationReporter):
         """
 
         files = []
-        packages = [pkg for pkg in xml_document.findall(".//package")]
+        packages = list(xml_document.findall(".//package"))
         for pkg in packages:
             _files = [
                 _file
@@ -173,14 +173,13 @@ class XmlCoverageReporter(BaseViolationReporter):
                 if self._measured_source_path_matches(
                     pkg.get("name"), _file.get("name"), src_path
                 )
-                or []
             ]
             files.extend(_files)
 
         if not files:
             return None
         lines = [file_tree.findall("./line") for file_tree in files]
-        return [elem for elem in itertools.chain(*lines)]
+        return list(itertools.chain(*lines))
 
     def _cache_file(self, src_path):
         """
